==> go.php?file=PhoenixStyle1.53903.zip: PhoenixStyleMod_Firelands/PhoenixStyleMod_Firelands.lua <==
﻿function psfirelload()

psfirellocalem()

if GetLocale()=="deDE" or GetLocale()=="ruRU" or GetLocale()=="zhTW" or GetLocale()=="zhCN" or GetLocale()=="frFR" or GetLocale()=="koKR" or GetLocale()=="esES" or GetLocale()=="esMX" then
psfirellocale()
end

--description of the menu
psraidoptionstxtt2={}
psraidoptionstxtt2[1]={
{"opt1_boss1"},
{"opt1_boss2"},
{"|tip2 "..psfireldamagefrom.." |sid98463|id", "|tip2 "..psfireldamagefrom.." |sid99844|id",pscmrtxtopt533, "|tip2 "..psfireldamagefrom.." |sid99794|id", "|tip2 "..psfireldamagefrom.." |sid99816|id", "|tip2 "..psfireldamagefrom.." |sid99336|id", "|tip2 "..psfireldamagefrom.." |sid98885|id", "|tip2 "..psfireldamagefrom.." |sid99427|id"},
{},
{},
{},
{}
}


for i=1,#psraidoptionstxtt2 do
	for j=1,#psraidoptionstxtt2[i] do
		for k=1,#psraidoptionstxtt2[i][j] do
			psraidoptionstxtt2[i][j][k]=psspellfilter(psraidoptionstxtt2[i][j][k])
		end
	end
end

--chat settings 1 or 2 or 3
psraidoptionschatdeft2={}
psraidoptionschatdeft2[1]={{1},{1},{1,1,1,1,1,1,1,1}}


--chat settings on or off
psraidoptionsondeft2={}
psraidoptionsondeft2[1]={{1},{1},{1,1,1,1,1,1,1,1}}



SetMapToCurrentZone()
if GetCurrentMapAreaID()==pslocations[5] then
	PhoenixStyleMod_firel:RegisterEvent("COMBAT_LOG_EVENT_UNFILTERED")
end
	PhoenixStyleMod_firel:RegisterEvent("PLAYER_REGEN_DISABLED")
	PhoenixStyleMod_firel:RegisterEvent("ZONE_CHANGED_NEW_AREA")
	PhoenixStyleMod_firel:RegisterEvent("ADDON_LOADED")
end



--онапдейт
function psfirelonupdate(curtime)


--ыытест удалить
--УБрать переменную что сейвит день!!!
--psgiveuslogs
--local _, month, day, year = CalendarGetDate()
if reportinsec7 and curtime>reportinsec7 then
reportinsec7=nil
local _, month, day, year = CalendarGetDate()
	if month<=6 and select(4, GetBuildInfo())>=40200 then
		if psgiveuslogs==nil or (psgiveuslogs and psgiveuslogs~=day) then
			psgiveuslogs=day
			local tx="|cff00ff00We need Combat Logs|r. Please if you have time upload them on |cff00ff00www.phoenixstyle.com/logs|r you will help us to update many addons that use this service!"
			if GetLocale()=="ruRU" then
				tx="|cff00ff00Нам нужны Комбат логи|r. Чтобы помочь нам с обновлением многих аддонов, которые используют наш новый сервис, загляните на сайт - |cff00ff00www.phoenixstyle.com/logs|r"
			end
			out("|cff99ffffPhoenixStyle|r - "..tx)
		end
	end
end



--evade after 3 sec
if pscmrcheckforevade2 and curtime>pscmrcheckforevade2 then
pscmrcheckforevade2=pscmrcheckforevade2+7
local id=0
if UnitGUID("boss1") then
	id=tonumber(string.sub(UnitGUID("boss1"),-12,-9),16)
end
local bil=0
if #psbossbugs>0 then
	for i=1,#psbossbugs do
		if psbossbugs[i]==id then
			bil=1
		end
	end
end
if (UnitName("boss1")==nil and UnitName("boss2")==nil and UnitName("boss3")==nil) or bil==1 or (UnitName("boss1") and UnitName("boss1")=="") then
psiccwipereport_2(nil,"try")
end
end


if pscatamrdelayzone_2 and curtime>pscatamrdelayzone_2 then
pscatamrdelayzone_2=nil
local a1, a2, a3, a4, a5 = GetInstanceInfo()
if UnitInRaid("player") or (a2=="raid" or (a2=="party" and a3==2)) then
SetMapToCurrentZone()
end
if GetCurrentMapAreaID()==pslocations[5] then
PhoenixStyleMod_firel:RegisterEvent("COMBAT_LOG_EVENT_UNFILTERED")
else
PhoenixStyleMod_firel:UnregisterEvent("COMBAT_LOG_EVENT_UNFILTERED")
end
end

--announce delay for phasing
if psiccrepupdate_2 and curtime>psiccrepupdate_2 then
psiccrepupdate_2=nil
psiccwipereport_2(psdelcount1,psdelcount2,psdelcount3)
psdelcount1=nil
psdelcount2=nil
psdelcount3=nil
end

--прерванные бои
if pscheckbossincombatmcr_2 and GetTime()>pscheckbossincombatmcr_2 then
	pscheckbossincombatmcr_2=pscheckbossincombatmcr_2+2


local id=0
if UnitGUID("boss1") then
	id=tonumber(string.sub(UnitGUID("boss1"),-12,-9),16)
end
local bil=0
if #psbossbugs>0 then
	for i=1,#psbossbugs do
		if psbossbugs[i]==id then
			bil=1
		end
	end
end

	if UnitGUID("boss1") and bil==0 and UnitName("boss1")~="" then
	else
		pscheckbossincombatmcr_2=nil
		pscheckbossincombatmcr_22=GetTime()+1
	end
end

if pscheckbossincombatmcr_22 and GetTime()>pscheckbossincombatmcr_22 then
	pscheckbossincombatmcr_22=nil
	if psbossblock==nil then
		psiccwipereport_2(nil, nil, "reset")
	end
end

if pscatadelaycheckboss_2 and curtime>pscatadelaycheckboss_2 then
pscatadelaycheckboss_2=nil


	if UnitGUID("boss1") then
		local id2=UnitGUID("boss1")
		local id=tonumber(string.sub(id2,-12,-9),16)
local bil=0
if #psbossbugs>0 then
	for i=1,#psbossbugs do
		if psbossbugs[i]==id then
			bil=1
		end
	end
end
		if bil==0 and UnitName("boss1")~="" then
			pscmroncombatstartcheckboss_2(id)
		else
			pscmrdelayofbosccheck_2=GetTime()+1
		end
	else
		pscmrdelayofbosccheck_2=GetTime()+1
	end
end


--постоянная проверка по ходу боя...
if pscmrdelayofbosccheck_2 and curtime>pscmrdelayofbosccheck_2 then
pscmrdelayofbosccheck_2=curtime+1


	if UnitGUID("boss1") then
		local id2=UnitGUID("boss1")
		local id=tonumber(string.sub(id2,-12,-9),16)
local bil=0
if #psbossbugs>0 then
	for i=1,#psbossbugs do
		if psbossbugs[i]==id then
			bil=1
		end
	end
end
		if bil==0 and UnitName("boss1")~="" then
			pscmroncombatstartcheckboss_2(id)
			pscmrdelayofbosccheck_2=nil
		end
	end
end






end

function pscmroncombatstartcheckboss_2(id)



SetMapToCurrentZone()
if GetCurrentMapAreaID()==pslocations[5] then
pscmrcheckforevade2=GetTime()+10
end


	--ыыытест новые боссы прописывать тут (2 места)
--ыый не прописаны ИД еще!


if GetCurrentMapAreaID()==pslocations[5] then
	if id==52498 and psbossfile51 then
		pswasonboss51=1
	end
	if id==52558 and psbossfile52 then
		pswasonboss52=1
	end
	if id==52530 and psbossfile53 then
		pswasonboss53=1
	end
end


end


function psfirelonevent(self,event,...)


if event == "COMBAT_LOG_EVENT_UNFILTERED" then


--Inst 5
if GetCurrentMapAreaID()==pslocations[5] then

if pswasonboss51 then
pscombatlogboss51(...)
elseif pswasonboss52 then
pscombatlogboss52(...)
elseif pswasonboss53 then
pscombatlogboss53(...)
elseif pswasonboss54 then
pscombatlogboss54(...)
elseif pswasonboss55 then
pscombatlogboss55(...)
elseif pswasonboss56 then
pscombatlogboss56(...)
elseif pswasonboss57 then
pscombatlogboss57(...)

else --ыытест только для теста в понедельник!
--pscombatlogboss55(...) --ыытест только для теста в понедельник!

end

end






else

--остальные евенты

local arg1, arg2, arg3,arg4,arg5,arg6 = ...

if event == "PLAYER_REGEN_DISABLED" then


else


if UnitGUID("boss1") then
local id2=UnitGUID("boss1")
local id=tonumber(string.sub(id2,-12,-9),16)
local bil=0
if #psbossbugs>0 then
	for i=1,#psbossbugs do
		if psbossbugs[i]==id then
			bil=1
		end
	end
end
if bil==0 and UnitName("boss1")~="" then
pscmroncombatstartcheckboss_2(id)
else
pscatadelaycheckboss_2=GetTime()+2
end

else
pscatadelaycheckboss_2=GetTime()+2
end


end





if event == "ZONE_CHANGED_NEW_AREA" then


psiccwipereport_2(nil,"try")
pscatamrdelayzone_2=GetTime()+3


end






if event == "ADDON_LOADED" then

if arg1=="PhoenixStyleMod_Firelands" then

--ыытест
--УБрать переменную что сейвит день!!!
--psgiveuslogs
--local _, month, day, year = CalendarGetDate()
reportinsec7=GetTime()+7


if psicctekver_2==nil then psicctekver_2=0 end


local psiccnewveranoncet={}
if GetLocale()=="ruRU" then
psiccnewveranoncet={}
end 


--NEW announce
	if 0-psicctekver_2>0 then

local psvercoll=(0-psicctekver_2)

		if psvercoll>0 then
			print ("|cff99ffffPhoenixStyle|r - "..pscolnewveranonce1)
		end

if psvercoll>3 then psvercoll=3 end

while psvercoll>0 do
		if psvercoll>0 then
out ("|cff99ffffPhoenixStyle|r - "..psiccnewveranoncet[psvercoll])
		end
psvercoll=psvercoll-1
end
	end

psicctekver_2=0 --ТЕК ВЕРСИЯ!!! и так выше изменить цифру что отнимаем, всего 3 раза




pslastmoduleloadtxt=psfirellastmoduleloadtxt


--перенос переменных

pscmrpassvariables_2()


	if psraidoptionson[5]==nil then psraidoptionson[5]={}
	end
	for j=1,#psraidoptionsont2[1] do
		if psraidoptionson[5][j]==nil then
			psraidoptionson[5][j]={}
		end
		for t=1,#psraidoptionsont2[1][j] do
			if psraidoptionson[5][j][t]==nil then
				psraidoptionson[5][j][t]=psraidoptionsont2[1][j][t]
			end
		end
	end

	if psraidoptionstxt[5]==nil then psraidoptionstxt[5]={}
	end
	for j=1,#psraidoptionstxtt2[1] do
		if psraidoptionstxt[5][j]==nil then
			psraidoptionstxt[5][j]={}
		end
		for t=1,#psraidoptionstxtt2[1][j] do
			if psraidoptionstxt[5][j][t]==nil then
				psraidoptionstxt[5][j][t]=psraidoptionstxtt2[1][j][t]
			end
		end
	end

--ыытест

psraidoptionstxtt2=nil

	if psraidoptionschat[5]==nil then psraidoptionschat[5]={}
	end
	for j=1,#psraidoptionschatt2[1] do
		if psraidoptionschat[5][j]==nil then
			psraidoptionschat[5][j]={}
		end
		for t=1,#psraidoptionschatt2[1][j] do
			if psraidoptionschat[5][j][t]==nil then
				psraidoptionschat[5][j][t]=psraidoptionschatt2[1][j][t]
			end
		end
	end


--boss manual localization update
if psbossnames then

end



end
end
--остальные евенты конец





end --рейд


end --КОНЕЦ ОНЕВЕНТ


--tryorkill - if try then true, if kill - nil, reset - only reset no report
--pswasonboss42 1 если мы в бою с боссом и трекерим, 2 если вайпнулись и продолжаем трекерить ПОСЛЕ анонса
function psiccwipereport_2(wipe, tryorkill, reset, checkforwipe)
local aa=""
if wipe then
aa=aa.."wipe:"..wipe.."."
end
if tryorkill then
aa=aa.."tryorkill:"..tryorkill.."."
end
if reset then
aa=aa.."reset:"..reset.."."
end
if checkforwipe then
aa=aa.."checkforwipe:"..checkforwipe.."."
end


	if pszapuskdelayphasing_2>0 then
	psiccrepupdate_2=pszapuskdelayphasing_2
	pszapuskdelayphasing_2=0
	if psiccrepupdate_2>7 then psiccrepupdate_2=7 end
	psiccrepupdate_2=psiccrepupdate_2+GetTime()
	psdelcount1=wipe
	psdelcount2=tryorkill
	psdelcount3=reset
	else

		if psiccrepupdate_2==nil then

--ыыытест новые боссы прописывать тут (2 места)
pscmrcheckforevade2=nil


if (pswasonboss51) then
pscmrbossREPORT511(wipe, tryorkill, reset, checkforwipe)
pscmrbossRESET511(wipe, tryorkill, reset, checkforwipe)
end
if (pswasonboss52) then
pscmrbossREPORT521(wipe, tryorkill, reset, checkforwipe)
pscmrbossRESET521(wipe, tryorkill, reset, checkforwipe)
end
if (pswasonboss53) then
pscmrbossREPORT531(wipe, tryorkill, reset, checkforwipe)
pscmrbossRESET531(wipe, tryorkill, reset, checkforwipe)
end
if (pswasonboss54) then
pscmrbossREPORT541(wipe, tryorkill, reset, checkforwipe)
pscmrbossRESET541(wipe, tryorkill, reset, checkforwipe)
end
if (pswasonboss55) then
pscmrbossREPORT551(wipe, tryorkill, reset, checkforwipe)
pscmrbossRESET551(wipe, tryorkill, reset, checkforwipe)
end
if (pswasonboss56) then
pscmrbossREPORT561(wipe, tryorkill, reset, checkforwipe)
pscmrbossRESET561(wipe, tryorkill, reset, checkforwipe)
end
if (pswasonboss57) then
pscmrbossREPORT571(wipe, tryorkill, reset, checkforwipe)
pscmrbossRESET571(wipe, tryorkill, reset, checkforwipe)
end

		end

	end

if wipe==nil then
psbossblock=GetTime()
end

end


function pscmrpassvariables_2()

if psraidoptionschatt2==nil then psraidoptionschatt2={} end

for i=1,#psraidoptionschatdeft2 do
	if psraidoptionschatt2[i]==nil then
		psraidoptionschatt2[i]={}
	end
	for j=1,#psraidoptionschatdeft2[i] do
		if psraidoptionschatt2[i][j]==nil then
			psraidoptionschatt2[i][j]={}
		end
		for t=1,#psraidoptionschatdeft2[i][j] do
			if psraidoptionschatt2[i][j][t]==nil or (psraidoptionschatt2[i][j][t] and psraidoptionschatt2[i][j][t]==0) then
				psraidoptionschatt2[i][j][t]=psraidoptionschatdeft2[i][j][t]
			end
		end
	end
end

if psraidoptionsont2==nil then psraidoptionsont2={} end

for i=1,#psraidoptionsondeft2 do
	if psraidoptionsont2[i]==nil then
		psraidoptionsont2[i]={}
	end
	for j=1,#psraidoptionsondeft2[i] do
		if psraidoptionsont2[i][j]==nil then
			psraidoptionsont2[i][j]={}
		end
		for t=1,#psraidoptionsondeft2[i][j] do
			if psraidoptionsont2[i][j][t]==nil then
				psraidoptionsont2[i][j][t]=psraidoptionsondeft2[i][j][t]
			end
		end
	end
end

end

==> go.php?file=PhoenixStyle1.54001.zip: PhoenixStyleMod_Firelands/PhoenixStyleMod_Firelands.lua <==
﻿function psfirelload()

psfirellocalem()

if GetLocale()=="deDE" or GetLocale()=="ruRU" or GetLocale()=="zhTW" or GetLocale()=="zhCN" or GetLocale()=="frFR" or GetLocale()=="koKR" or GetLocale()=="esES" or GetLocale()=="esMX" then
psfirellocale()
end

--description of the menu
psraidoptionstxtt2={}
psraidoptionstxtt2[1]={
{"|tip2 "..psfireldamagefrom.." |sid99076|id", psfiretxtopt512, "|tip2 "..psfireldamagefrom.." |sid99052|id"},
{},
{"|tip2 "..psfireldamagefrom.." |sid98463|id", "|tip2 "..psfireldamagefrom.." |sid99844|id",psfiretxtopt533, "|tip2 "..psfireldamagefrom.." |sid99794|id", "|tip2 "..psfireldamagefrom.." |sid99816|id", "|tip2 "..psfireldamagefrom.." |sid99336|id", "|tip2 "..psfireldamagefrom.." |sid98885|id", "|tip2 "..psfireldamagefrom.." |sid99427|id"},
{"|tip1 "..psfirelwhogot.. " |sid99837|id", "|tip2 "..psfirelwhogot.. " |sid99837|id ("..psfireltotal..")", "|tip2 "..psfirelwhogot.. " |sid99838|id ("..psfireltotal..")"},
{},
{},
{}
}


for i=1,#psraidoptionstxtt2 do
	for j=1,#psraidoptionstxtt2[i] do
		for k=1,#psraidoptionstxtt2[i][j] do
			psraidoptionstxtt2[i][j][k]=psspellfilter(psraidoptionstxtt2[i][j][k])
		end
	end
end

--chat settings 1 or 2 or 3
psraidoptionschatdeft2={}
psraidoptionschatdeft2[1]={{1,1,1},{},{1,1,1,1,1,1,1,1},{1,1,1}}


--chat settings on or off
psraidoptionsondeft2={}
psraidoptionsondeft2[1]={{1,1,1},{},{1,1,1,1,1,1,1,1},{1,1,1}}



SetMapToCurrentZone()
if GetCurrentMapAreaID()==pslocations[5] then
	PhoenixStyleMod_firel:RegisterEvent("COMBAT_LOG_EVENT_UNFILTERED")
end
	PhoenixStyleMod_firel:RegisterEvent("PLAYER_REGEN_DISABLED")
	PhoenixStyleMod_firel:RegisterEvent("ZONE_CHANGED_NEW_AREA")
	PhoenixStyleMod_firel:RegisterEvent("ADDON_LOADED")
end



--онапдейт
function psfirelonupdate(curtime)


--ыытест удалить
--УБрать переменную что сейвит день!!!
--psgiveuslogs
--local _, month, day, year = CalendarGetDate()
if reportinsec7 and curtime>reportinsec7 then
reportinsec7=nil
local _, month, day, year = CalendarGetDate()
	if month<=6 and select(4, GetBuildInfo())>=40200 then
		if psgiveuslogs==nil or (psgiveuslogs and psgiveuslogs~=day) then
			psgiveuslogs=day
			local tx="|cff00ff00We need Combat Logs|r. Please if you have time upload them on |cff00ff00http://www.phoenixstyle.com/logs|r you will help us to update many addons that use this service!"
			if GetLocale()=="ruRU" then
				tx="|cff00ff00Нам нужны Комбат логи|r. Чтобы помочь нам с обновлением многих аддонов, которые используют наш новый сервис, загляните на сайт - |cff00ff00http://www.phoenixstyle.com/logs|r"
			end
			out("|cff99ffffPhoenixStyle|r - "..tx)
		end
	end
end



--evade after 3 sec
if pscmrcheckforevade2 and curtime>pscmrcheckforevade2 then
pscmrcheckforevade2=pscmrcheckforevade2+7
local id=0
if UnitGUID("boss1") then
	id=tonumber(string.sub(UnitGUID("boss1"),-12,-9),16)
end
local bil=0
if #psbossbugs>0 then
	for i=1,#psbossbugs do
		if psbossbugs[i]==id then
			bil=1
		end
	end
end
if (UnitName("boss1")==nil and UnitName("boss2")==nil and UnitName("boss3")==nil) or bil==1 or (UnitName("boss1") and UnitName("boss1")=="") then
psiccwipereport_2(nil,"try")
end
end


if pscatamrdelayzone_2 and curtime>pscatamrdelayzone_2 then
pscatamrdelayzone_2=nil
local a1, a2, a3, a4, a5 = GetInstanceInfo()
if UnitInRaid("player") or (a2=="raid" or (a2=="party" and a3==2)) then
SetMapToCurrentZone()
end
if GetCurrentMapAreaID()==pslocations[5] then
PhoenixStyleMod_firel:RegisterEvent("COMBAT_LOG_EVENT_UNFILTERED")
else
PhoenixStyleMod_firel:UnregisterEvent("COMBAT_LOG_EVENT_UNFILTERED")
end
end

--announce delay for phasing
if psiccrepupdate_2 and curtime>psiccrepupdate_2 then
psiccrepupdate_2=nil
psiccwipereport_2(psdelcount1,psdelcount2,psdelcount3)
psdelcount1=nil
psdelcount2=nil
psdelcount3=nil
end

--прерванные бои
if pscheckbossincombatmcr_2 and GetTime()>pscheckbossincombatmcr_2 then
	pscheckbossincombatmcr_2=pscheckbossincombatmcr_2+2


local id=0
if UnitGUID("boss1") then
	id=tonumber(string.sub(UnitGUID("boss1"),-12,-9),16)
end
local bil=0
if #psbossbugs>0 then
	for i=1,#psbossbugs do
		if psbossbugs[i]==id then
			bil=1
		end
	end
end

	if UnitGUID("boss1") and bil==0 and UnitName("boss1")~="" then
	else
		pscheckbossincombatmcr_2=nil
		pscheckbossincombatmcr_22=GetTime()+1
	end
end

if pscheckbossincombatmcr_22 and GetTime()>pscheckbossincombatmcr_22 then
	pscheckbossincombatmcr_22=nil
	if psbossblock==nil then
		psiccwipereport_2(nil, nil, "reset")
	end
end

if pscatadelaycheckboss_2 and curtime>pscatadelaycheckboss_2 then
pscatadelaycheckboss_2=nil


	if UnitGUID("boss1") then
		local id2=UnitGUID("boss1")
		local id=tonumber(string.sub(id2,-12,-9),16)
local bil=0
if #psbossbugs>0 then
	for i=1,#psbossbugs do
		if psbossbugs[i]==id then
			bil=1
		end
	end
end
		if bil==0 and UnitName("boss1")~="" then
			pscmroncombatstartcheckboss_2(id)
		else
			pscmrdelayofbosccheck_2=GetTime()+1
		end
	else
		pscmrdelayofbosccheck_2=GetTime()+1
	end
end


--постоянная проверка по ходу боя...
if pscmrdelayofbosccheck_2 and curtime>pscmrdelayofbosccheck_2 then
pscmrdelayofbosccheck_2=curtime+1


	if UnitGUID("boss1") then
		local id2=UnitGUID("boss1")
		local id=tonumber(string.sub(id2,-12,-9),16)
local bil=0
if #psbossbugs>0 then
	for i=1,#psbossbugs do
		if psbossbugs[i]==id then
			bil=1
		end
	end
end
		if bil==0 and UnitName("boss1")~="" then
			pscmroncombatstartcheckboss_2(id)
			pscmrdelayofbosccheck_2=nil
		end
	end
end






end

function pscmroncombatstartcheckboss_2(id)



SetMapToCurrentZone()
if GetCurrentMapAreaID()==pslocations[5] then
pscmrcheckforevade2=GetTime()+10
end


	--ыыытест новые боссы прописывать тут (2 места)
--ыый не прописаны ИД еще!


if GetCurrentMapAreaID()==pslocations[5] then
	if id==52498 and psbossfile51 then
		pswasonboss51=1
	end
	if id==52558 and psbossfile52 then
		pswasonboss52=1
	end
	if id==52530 and psbossfile53 then
		pswasonboss53=1
	end
	if id==53691 and psbossfile54 then
		pswasonboss53=1
	end
	if id==53494 and psbossfile55 then
		pswasonboss53=1
	end
end


end


function psfirelonevent(self,event,...)


if event == "COMBAT_LOG_EVENT_UNFILTERED" then


--Inst 5
if GetCurrentMapAreaID()==pslocations[5] then

if pswasonboss51 then
pscombatlogboss51(...)
elseif pswasonboss52 then
pscombatlogboss52(...)
elseif pswasonboss53 then
pscombatlogboss53(...)
elseif pswasonboss54 then
pscombatlogboss54(...)
elseif pswasonboss55 then
pscombatlogboss55(...)
elseif pswasonboss56 then
pscombatlogboss56(...)
elseif pswasonboss57 then
pscombatlogboss57(...)

else --ыытест только для теста в понедельник!
pscombatlogboss51(...) --ыытест только для теста в пятницу!

end

end






else

--остальные евенты

local arg1, arg2, arg3,arg4,arg5,arg6 = ...

if event == "PLAYER_REGEN_DISABLED" then


else


if UnitGUID("boss1") then
local id2=UnitGUID("boss1")
local id=tonumber(string.sub(id2,-12,-9),16)
local bil=0
if #psbossbugs>0 then
	for i=1,#psbossbugs do
		if psbossbugs[i]==id then
			bil=1
		end
	end
end
if bil==0 and UnitName("boss1")~="" then
pscmroncombatstartcheckboss_2(id)
else
pscatadelaycheckboss_2=GetTime()+2
end

else
pscatadelaycheckboss_2=GetTime()+2
end


end





if event == "ZONE_CHANGED_NEW_AREA" then


psiccwipereport_2(nil,"try")
pscatamrdelayzone_2=GetTime()+3


end






if event == "ADDON_LOADED" then

if arg1=="PhoenixStyleMod_Firelands" then

--ыытест
--УБрать переменную что сейвит день!!!
--psgiveuslogs
--local _, month, day, year = CalendarGetDate()
reportinsec7=GetTime()+7


if psicctekver_2==nil then psicctekver_2=0 end


local psiccnewveranoncet={}
if GetLocale()=="ruRU" then
psiccnewveranoncet={}
end 


--NEW announce
	if 0-psicctekver_2>0 then

local psvercoll=(0-psicctekver_2)

		if psvercoll>0 then
			print ("|cff99ffffPhoenixStyle|r - "..pscolnewveranonce1)
		end

if psvercoll>3 then psvercoll=3 end

while psvercoll>0 do
		if psvercoll>0 then
out ("|cff99ffffPhoenixStyle|r - "..psiccnewveranoncet[psvercoll])
		end
psvercoll=psvercoll-1
end
	end

psicctekver_2=0 --ТЕК ВЕРСИЯ!!! и так выше изменить цифру что отнимаем, всего 3 раза




pslastmoduleloadtxt=psfirellastmoduleloadtxt


--перенос переменных

pscmrpassvariables_2()


	if psraidoptionson[5]==nil then psraidoptionson[5]={}
	end
	for j=1,#psraidoptionsont2[1] do
		if psraidoptionson[5][j]==nil then
			psraidoptionson[5][j]={}
		end
		for t=1,#psraidoptionsont2[1][j] do
			if psraidoptionson[5][j][t]==nil then
				psraidoptionson[5][j][t]=psraidoptionsont2[1][j][t]
			end
		end
	end

	if psraidoptionstxt[5]==nil then psraidoptionstxt[5]={}
	end
	for j=1,#psraidoptionstxtt2[1] do
		if psraidoptionstxt[5][j]==nil then
			psraidoptionstxt[5][j]={}
		end
		for t=1,#psraidoptionstxtt2[1][j] do
			if psraidoptionstxt[5][j][t]==nil then
				psraidoptionstxt[5][j][t]=psraidoptionstxtt2[1][j][t]
			end
		end
	end

--ыытест

psraidoptionstxtt2=nil

	if psraidoptionschat[5]==nil then psraidoptionschat[5]={}
	end
	for j=1,#psraidoptionschatt2[1] do
		if psraidoptionschat[5][j]==nil then
			psraidoptionschat[5][j]={}
		end
		for t=1,#psraidoptionschatt2[1][j] do
			if psraidoptionschat[5][j][t]==nil then
				psraidoptionschat[5][j][t]=psraidoptionschatt2[1][j][t]
			end
		end
	end


--boss manual localization update
if psbossnames then

end



end
end
--остальные евенты конец





end --рейд


end --КОНЕЦ ОНЕВЕНТ


--tryorkill - if try then true, if kill - nil, reset - only reset no report
--pswasonboss42 1 если мы в бою с боссом и трекерим, 2 если вайпнулись и продолжаем трекерить ПОСЛЕ анонса
function psiccwipereport_2(wipe, tryorkill, reset, checkforwipe)
local aa=""
if wipe then
aa=aa.."wipe:"..wipe.."."
end
if tryorkill then
aa=aa.."tryorkill:"..tryorkill.."."
end
if reset then
aa=aa.."reset:"..reset.."."
end
if checkforwipe then
aa=aa.."checkforwipe:"..checkforwipe.."."
end


	if pszapuskdelayphasing_2>0 then
	psiccrepupdate_2=pszapuskdelayphasing_2
	pszapuskdelayphasing_2=0
	if psiccrepupdate_2>7 then psiccrepupdate_2=7 end
	psiccrepupdate_2=psiccrepupdate_2+GetTime()
	psdelcount1=wipe
	psdelcount2=tryorkill
	psdelcount3=reset
	else

		if psiccrepupdate_2==nil then

--ыыытест новые боссы прописывать тут (2 места)
pscmrcheckforevade2=nil


if (pswasonboss51) then
pscmrbossREPORT511(wipe, tryorkill, reset, checkforwipe)
pscmrbossRESET511(wipe, tryorkill, reset, checkforwipe)
end
if (pswasonboss52) then
pscmrbossREPORT521(wipe, tryorkill, reset, checkforwipe)
pscmrbossRESET521(wipe, tryorkill, reset, checkforwipe)
end
if (pswasonboss53) then
pscmrbossREPORT531(wipe, tryorkill, reset, checkforwipe)
pscmrbossRESET531(wipe, tryorkill, reset, checkforwipe)
end
if (pswasonboss54) then
pscmrbossREPORT541(wipe, tryorkill, reset, checkforwipe)
pscmrbossRESET541(wipe, tryorkill, reset, checkforwipe)
end
if (pswasonboss55) then
pscmrbossREPORT551(wipe, tryorkill, reset, checkforwipe)
pscmrbossRESET551(wipe, tryorkill, reset, checkforwipe)
end
if (pswasonboss56) then
pscmrbossREPORT561(wipe, tryorkill, reset, checkforwipe)
pscmrbossRESET561(wipe, tryorkill, reset, checkforwipe)
end
if (pswasonboss57) then
pscmrbossREPORT571(wipe, tryorkill, reset, checkforwipe)
pscmrbossRESET571(wipe, tryorkill, reset, checkforwipe)
end

		end

	end

if wipe==nil then
psbossblock=GetTime()
end

end


function pscmrpassvariables_2()

if psraidoptionschatt2==nil then psraidoptionschatt2={} end

for i=1,#psraidoptionschatdeft2 do
	if psraidoptionschatt2[i]==nil then
		psraidoptionschatt2[i]={}
	end
	for j=1,#psraidoptionschatdeft2[i] do
		if psraidoptionschatt2[i][j]==nil then
			psraidoptionschatt2[i][j]={}
		end
		for t=1,#psraidoptionschatdeft2[i][j] do
			if psraidoptionschatt2[i][j][t]==nil or (psraidoptionschatt2[i][j][t] and psraidoptionschatt2[i][j][t]==0) then
				psraidoptionschatt2[i][j][t]=psraidoptionschatdeft2[i][j][t]
			end
		end
	end
end

if psraidoptionsont2==nil then psraidoptionsont2={} end

for i=1,#psraidoptionsondeft2 do
	if psraidoptionsont2[i]==nil then
		psraidoptionsont2[i]={}
	end
	for j=1,#psraidoptionsondeft2[i] do
		if psraidoptionsont2[i][j]==nil then
			psraidoptionsont2[i][j]={}
		end
		for t=1,#psraidoptionsondeft2[i][j] do
			if psraidoptionsont2[i][j][t]==nil then
				psraidoptionsont2[i][j][t]=psraidoptionsondeft2[i][j][t]
			end
		end
	end
end

end
